==> mgb-0.5.4.4-de.zip: install/update.php <==
<?php
	/*
	MGB 0.5.4.4
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "../config.php";
         include "../language/lang_update.php";

         if($_GET[action]=="update")
         	{
         	if($_POST[sent] != 1)
         		{
                 	$ausgabe="<br><br><font class='normal'>".$lang['instructions']."</font><br><br>";
                		$ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
			$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
                 	$ausgabe.="<select name='version' size='1'><option selected value='1'>0.5 - 0.5.3</option><option value='2'>0.5.4 - 0.5.4.2</option><option value='3'>0.5.4.3</option></select><br><br>\n";
                         if($db[user] == "" OR $db[host] == "" OR $db[password] == "" OR $db[dbname] == "" OR $db[settings] == "" OR $db[entrys] == "" OR $db[captcha] == "")
				{
				$ausgabe.="<font class='fehler'>".$lang['missingdata']."</font><br>";
				}
			else
				{
         			$ausgabe.="<input type='submit' value='".$lang['button_value']."'>\n";
				}
         		$ausgabe.="</form>\n";
			$ausgabe.="</center>\n";
                 	}
         	if($_POST[sent] == 1)
         		{
			if($_POST[version] == 1)
				{
                         	$eintrag[1] = "ALTER TABLE `".$db[settings]."` ADD `moderated` TINYINT( 1 ) NOT NULL DEFAULT '1' AFTER `keywords` ;";
         			$eintrag[2] = "ALTER TABLE `".$db[settings]."` DROP `quakemessage` ;";
         			$eintrag[3] = "ALTER TABLE `".$db[settings]."` ADD `bbcodes` TINYINT( 1 ) NOT NULL AFTER `smilies` ;";
                         	$eintrag[4] = "ALTER TABLE `".$db[entrys]."` CHANGE `checked` `checked` TINYINT( 2 ) NULL DEFAULT '' ;";
				$eintrag[5] = "CREATE TABLE `".$db[captcha]."` (`code` VARCHAR( 11 ) NOT NULL) Type=MyISAM ;";
				$eintrag[6] = "INSERT INTO `".$db[captcha]."` ( `code` ) VALUES ( 'A B C D E F' );";
				$eintrag[7] = "ALTER TABLE `".$db[settings]."` ADD `description` MEDIUMTEXT NOT NULL AFTER `keywords` ;";
				$eintrag[8] = "ALTER TABLE `".$db[settings]."` ADD `cookie` TINYINT( 1 ) NOT NULL AFTER `adminalerttries` ;";
                                 $eintrag[9] = "ALTER TABLE `".$db[settings]."` ADD `captcha` TINYINT( 1 ) NOT NULL AFTER `cookie` ;";
				$eintrag[10]= "ALTER TABLE `".$db[settings]."` ADD `ipsperre` TINYINT( 1 ) NOT NULL AFTER `captcha` ;";


                                 for($i = 1; $i <= 10; $i++)
					{
                         		$sql = $eintrag[$i];
					$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
					mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
					mysql_query($sql, $link) or die ("MySQL Fehler");
                                 	}
				}
			elseif($_POST[version] == 2)
				{
				$eintrag[1] = "CREATE TABLE `".$db[captcha]."` (`code` VARCHAR( 11 ) NOT NULL) Type=MyISAM ;";
				$eintrag[2] = "INSERT INTO `".$db[captcha]."` ( `code` ) VALUES ( 'A B C D E F' );";
				$eintrag[3] = "ALTER TABLE `".$db[settings]."` ADD `description` MEDIUMTEXT NOT NULL AFTER `keywords` ;";
				$eintrag[4] = "ALTER TABLE `".$db[settings]."` ADD `cookie` TINYINT( 1 ) NOT NULL AFTER `adminalerttries` ;";
				$eintrag[5] = "ALTER TABLE `".$db[settings]."` ADD `captcha` TINYINT( 1 ) NOT NULL AFTER `cookie` ;";
				$eintrag[6]= "ALTER TABLE `".$db[settings]."` ADD `ipsperre` TINYINT( 1 ) NOT NULL AFTER `captcha` ;";

                                 for($i = 1; $i <= 6; $i++)
					{
                                 	$sql = $eintrag[$i];
					$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
					mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
					mysql_query($sql, $link) or die ("MySQL Fehler");
					}
				}
			elseif($_POST[version] == 3)
				{
				$eintrag[1] = "ALTER TABLE `".$db[settings]."` ADD `description` MEDIUMTEXT NOT NULL AFTER `keywords` ;";
				$eintrag[2] = "ALTER TABLE `".$db[settings]."` ADD `cookie` TINYINT( 1 ) NOT NULL AFTER `adminalerttries` ;";
				$eintrag[3] = "ALTER TABLE `".$db[settings]."` ADD `captcha` TINYINT( 1 ) NOT NULL AFTER `cookie` ;";
				$eintrag[4] = "ALTER TABLE `".$db[settings]."` ADD `ipsperre` TINYINT( 1 ) NOT NULL AFTER `captcha` ;";

                                 for($i = 1; $i <= 4; $i++)
					{
                                 	$sql = $eintrag[$i];
					$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
					mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
					mysql_query($sql, $link) or die ("MySQL Fehler");
					}
				}

			$ausgabe="<br><br><font class='normal'>".$lang['success']."<br><br><a href='../guestbook.php'>".$lang['to_gb']."</a><br><a href='../passwort.php'>".$lang['to_admin']."</a><br><br><br>".$lang['hf']."&nbsp;<a href='http://www.tv-kritik.net/mgb/index.php'>http://www.tv-kritik.net/mgb/index.php</a></font></center>";
                         }
                 }
         else
         	{
                 $ausgabe="<br><br><font class='normal'>".$lang['license']."<br><br>".$lang['freeware']."</font><br><br>";
                 $ausgabe.="<iframe src='../onlinehilfe/gnugpl.html' style='border:2px solid #000000;height:400px;width:500px'><a href='../onlinehilfe/gnugpl.html' target='_blank'>GNU GPL</a></iframe>";
                 $ausgabe.="<br><br>";
                 $ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
                 $ausgabe.="<input type='submit' value='OK'>\n";
                 $ausgabe.="</form>\n";
         	$ausgabe.="</center>\n";
                 }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $lang['title']; ?></title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<meta name="description" content="Update des MGB">
<meta name="robots" content="noindex,nofollow">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="copyright" content="MGB 0.5.4.4  Copyright 2004-2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<style type="text/css">
<!--
	a:link{color:#ffffff;}
         a:active{color:#ffffff;}
         a:visited{color:#ffffff;}
         a:hover{color:#FFDF00;}

         font.normal
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#ffffff;
                 font-size:12px;
                 }
         font.fehler
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#DF0000;
                 font-size:12px;
                 }
         font.ganzunten
		{
                 font-size:10px;
                 color:#ffffff;
                 font-family:verdana,arial,helvetica,sans-serif;
        		}
         font.copyright
		{
        		font-size:10px;
        		color:#FFFFFF;
        		font-family:verdana;
        		}
         input
         	{
                 border:2px solid #9F9F9F;
                 background-color:#6F6F6F;
                 color:#FFFFFF;
                 }
         body
         	{
                 background-color:#9F9F9F;
                 }
// -->
</style>
</head>
<body>
<center>
<div style="border:2px solid #000000;background-color:#ffffff;padding:10px;width:500px">
<span style="color:#000000;font-size:16px;padding:3px;font-family:verdana,arial,helvetica,sans-serif;font-weight:bold"><?php echo $lang['title']; ?></span>
</div>
<br>
<center>
<br>
<font class='normal'><?php echo $lang['greetz']; ?></font>
<?php
         echo $ausgabe;
	include "../copyright.php";
?>
</center>
</body>
</html>

==> mgb-0.5.4.7-de.zip: install/update.php <==
<?php
	/*
	MGB 0.5.4.7
	Copyright (C) 2004 - 2007  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

        require "../config.php";
        require "../language/lang_update.php";

        if($_GET[action]=="update")
         	{
         	if($_POST[sent] != 1)
         		{
                 	$ausgabe="<br><br><font class='normal'>".$lang['instructions']."</font><br><br>";
                	$ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
			$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
                 	$ausgabe.="<select name='version' size='1'><option selected value='1'>0.5 - 0.5.3</option><option value='2'>0.5.4 - 0.5.4.2</option><option value='3'>0.5.4.3</option></select><br><br>\n";
                        if($db[user] == "" OR $db[host] == "" OR $db[password] == "" OR $db[dbname] == "" OR $db[settings] == "" OR $db[entrys] == "" OR $db[captcha] == "")
				{
				$ausgabe.="<font class='fehler'>".$lang['missingdata']."</font><br>";
				}
			else
				{
         			$ausgabe.="<input type='submit' value='".$lang['button_value']."'>\n";
				}
         		$ausgabe.="</form>\n";
			$ausgabe.="</center>\n";
                 	}
         	if($_POST[sent] == 1)
         		{
			if($_POST[version] == 1)
				{
                         	$eintrag[1] = "ALTER TABLE `".$db[settings]."` ADD `moderated` TINYINT( 1 ) NOT NULL DEFAULT '1' AFTER `keywords` ;";
         			$eintrag[2] = "ALTER TABLE `".$db[settings]."` DROP `quakemessage` ;";
         			$eintrag[3] = "ALTER TABLE `".$db[settings]."` ADD `bbcodes` TINYINT( 1 ) NOT NULL AFTER `smilies` ;";
                         	$eintrag[4] = "ALTER TABLE `".$db[entrys]."` CHANGE `checked` `checked` TINYINT( 2 ) NULL DEFAULT '' ;";
				$eintrag[5] = "CREATE TABLE `".$db[captcha]."` (`code` VARCHAR( 11 ) NOT NULL) Type=MyISAM ;";
				$eintrag[6] = "INSERT INTO `".$db[captcha]."` ( `code` ) VALUES ( 'A B C D E F' );";
				$eintrag[7] = "ALTER TABLE `".$db[settings]."` ADD `description` MEDIUMTEXT NOT NULL AFTER `keywords` ;";
				$eintrag[8] = "ALTER TABLE `".$db[settings]."` ADD `cookie` TINYINT( 1 ) NOT NULL AFTER `adminalerttries` ;";
                                $eintrag[9] = "ALTER TABLE `".$db[settings]."` ADD `captcha` TINYINT( 1 ) NOT NULL AFTER `cookie` ;";
				$eintrag[10]= "ALTER TABLE `".$db[settings]."` ADD `ipsperre` TINYINT( 1 ) NOT NULL AFTER `captcha` ;";


                                for($i = 1; $i <= 10; $i++)
					{
                         		$sql = $eintrag[$i];
					$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
					mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
					mysql_query($sql, $link) or die ("MySQL Fehler");
                                 	}
				}
			elseif($_POST[version] == 2)
				{
				$eintrag[1] = "CREATE TABLE `".$db[captcha]."` (`code` VARCHAR( 11 ) NOT NULL) Type=MyISAM ;";
				$eintrag[2] = "INSERT INTO `".$db[captcha]."` ( `code` ) VALUES ( 'A B C D E F' );";
				$eintrag[3] = "ALTER TABLE `".$db[settings]."` ADD `description` MEDIUMTEXT NOT NULL AFTER `keywords` ;";
				$eintrag[4] = "ALTER TABLE `".$db[settings]."` ADD `cookie` TINYINT( 1 ) NOT NULL AFTER `adminalerttries` ;";
				$eintrag[5] = "ALTER TABLE `".$db[settings]."` ADD `captcha` TINYINT( 1 ) NOT NULL AFTER `cookie` ;";
				$eintrag[6]= "ALTER TABLE `".$db[settings]."` ADD `ipsperre` TINYINT( 1 ) NOT NULL AFTER `captcha` ;";

                                for($i = 1; $i <= 6; $i++)
					{
                                 	$sql = $eintrag[$i];
					$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
					mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
					mysql_query($sql, $link) or die ("MySQL Fehler");
					}
				}
			elseif($_POST[version] == 3)
				{
				$eintrag[1] = "ALTER TABLE `".$db[settings]."` ADD `description` MEDIUMTEXT NOT NULL AFTER `keywords` ;";
				$eintrag[2] = "ALTER TABLE `".$db[settings]."` ADD `cookie` TINYINT( 1 ) NOT NULL AFTER `adminalerttries` ;";
				$eintrag[3] = "ALTER TABLE `".$db[settings]."` ADD `captcha` TINYINT( 1 ) NOT NULL AFTER `cookie` ;";
				$eintrag[4] = "ALTER TABLE `".$db[settings]."` ADD `ipsperre` TINYINT( 1 ) NOT NULL AFTER `captcha` ;";

                                for($i = 1; $i <= 4; $i++)
					{
                                 	$sql = $eintrag[$i];
					$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
					mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
					mysql_query($sql, $link) or die ("MySQL Fehler");
					}
				}

			$ausgabe="<br><br><font class='normal'>".$lang['success']."<br><br><a href='../guestbook.php'>".$lang['to_gb']."</a><br><a href='../passwort.php'>".$lang['to_admin']."</a><br><br><br>".$lang['hf']."&nbsp;<a href='http://www.tv-kritik.net/mgb/index.php'>http://www.tv-kritik.net/mgb/index.php</a></font></center>";
                        }
                 }
         else
         	{
                $ausgabe="<br><br><font class='normal'>".$lang['license']."<br><br>".$lang['freeware']."</font><br><br>";
                $ausgabe.="<iframe src='../onlinehilfe/gnugpl.html' style='border:2px solid #000000;height:400px;width:500px'><a href='../onlinehilfe/gnugpl.html' target='_blank'>GNU GPL</a></iframe>";
                $ausgabe.="<br><br>";
                $ausgabe.="<form method='post' action='".$PHP_SELF."?action=update'>";
                $ausgabe.="<input type='submit' value='OK'>\n";
                $ausgabe.="</form>\n";
         	$ausgabe.="</center>\n";
                }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $lang['title']; ?></title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses gstebuch, kostenloses php gstebuch">
<meta name="description" content="Update des MGB">
<meta name="robots" content="noindex,nofollow">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="copyright" content="MGB 0.5.4.7  Copyright 2004-2007 by mopzz -- http://www.m-gb.org/">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<style type="text/css">
<!--
	a:link{color:#ffffff;}
         a:active{color:#ffffff;}
         a:visited{color:#ffffff;}
         a:hover{color:#FFDF00;}

         font.normal
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#ffffff;
                 font-size:12px;
                 }
         font.fehler
         	{
                 font-family:verdana,arial,helvetica,sans-serif;
                 color:#DF0000;
                 font-size:12px;
                 }
         font.ganzunten
		{
                 font-size:10px;
                 color:#ffffff;
                 font-family:verdana,arial,helvetica,sans-serif;
        		}
         font.copyright
		{
        		font-size:10px;
        		color:#FFFFFF;
        		font-family:verdana;
        		}
         input
         	{
                 border:2px solid #9F9F9F;
                 background-color:#6F6F6F;
                 color:#FFFFFF;
                 }
         body
         	{
                 background-color:#9F9F9F;
                 }
// -->
</style>
</head>
<body>
<center>
<div style="border:2px solid #000000;background-color:#ffffff;padding:10px;width:500px">
<span style="color:#000000;font-size:16px;padding:3px;font-family:verdana,arial,helvetica,sans-serif;font-weight:bold"><?php echo $lang['title']; ?></span>
</div>
<br>
<center>
<br>
<font class='normal'><?php echo $lang['greetz']; ?></font>
<?php
         echo $ausgabe;
	include "../copyright.php";
?>
</center>
</body>
</html>
